==> kpimtextedit-19.03.80.tar.xz: kpimtextedit-19.03.80/src/textutils.h <==
/*
    This file is part of KDE.

    Copyright (c) 2009 Thomas McGuire <mcguire@kde.org>
    Copyright (c) 2010 Stephen Kelly <steveire@gmail.com>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef KPIMTEXTEDIT_TEXTUTILS_H
#define KPIMTEXTEDIT_TEXTUTILS_H

#include "kpimtextedit_export.h"
#include <qglobal.h>

class QTextDocument;

namespace KPIMTextEdit {
/**
  Utility class for methods working with rich text.

  @since 4.5
*/
namespace TextUtils {
/**
   * Returns whether the QTextDocument @p document contains rich text formatting.
   */
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT bool containsFormatting(const QTextDocument *document);

/**
   *  Changes the given text so that each line of it fits into the given maximal length.
   *  At each line, the "indent" string is prepended, which is usually the quote prefix.
   *  The text parameter will be empty afterwards.
   *  @param text the text to indent
   *  @param indent the indentation prefix string
   *  @param maxLength the maximal length the string of text will fit into
   *  Example:
   *    text = "Hello World, this is a test."
   *    indent = "> "
   *    maxLength = 16
   *    Result: "> Hello World,\n"
   *            "> this is a test."
   */
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QString flowText(QString &text, const QString &indent, int maxLength);

KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFullEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFacesEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeAnimalsEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeEmotionEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeBodyEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeTransportEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeEventEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFlagsEmoji();
}
}

#endif

==> kpimtextedit-19.03.90.tar.xz: kpimtextedit-19.03.90/src/textutils.h <==
/*
    This file is part of KDE.

    Copyright (c) 2009 Thomas McGuire <mcguire@kde.org>
    Copyright (c) 2010 Stephen Kelly <steveire@gmail.com>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#ifndef KPIMTEXTEDIT_TEXTUTILS_H
#define KPIMTEXTEDIT_TEXTUTILS_H

#include "kpimtextedit_export.h"
#include <qglobal.h>

class QTextDocument;

namespace KPIMTextEdit {
/**
  Utility class for methods working with rich text.

  @since 4.5
*/
namespace TextUtils {
/**
   * Returns whether the QTextDocument @p document contains rich text formatting.
   */
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT bool containsFormatting(const QTextDocument *document);

/**
   *  Changes the given text so that each line of it fits into the given maximal length.
   *  At each line, the "indent" string is prepended, which is usually the quote prefix.
   *  The text parameter will be empty afterwards.
   *  @param text the text to indent
   *  @param indent the indentation prefix string
   *  @param maxLength the maximal length the string of text will fit into
   *  Example:
   *    text = "Hello World, this is a test."
   *    indent = "> "
   *    maxLength = 16
   *    Result: "> Hello World,\n"
   *            "> this is a test."
   */
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QString flowText(QString &text, const QString &indent, int maxLength);

KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFullEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFacesEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeAnimalsEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeEmotionEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeBodyEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeTransportEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeEventEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFlagsEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeWeatherEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFoodEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeSportEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeTimeEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeGameEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeClothingEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeSoundMusicEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeComputerEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeSymbolsEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFaceEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeFantasyEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodePlantEmoji();
KPIMTEXTEDIT_EXPORT Q_REQUIRED_RESULT QList<uint> unicodeTravelEmoji();
}
}

#endif
